#
# spec file for package rmw
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rmw
Version:        0.9.3
Release:        1.4
Summary:        Safe-remove utility for the command line
License:        GPL-3.0-or-later
Group:          System/Management
URL:            https://theimpossibleastronaut.github.io/rmw-website
Source:         https://github.com/theimpossibleastronaut/rmw/releases/download/v%{version}/%{name}-%{version}.tar.xz
BuildRequires:  meson >= 0.59.0
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  pkgconfig(ncurses)

%description
rmw (ReMove to Waste) is a safe-remove utility for the command line. It
can move and restore files to and from directories specified in a
configuration file, and can also be integrated with your regular
desktop trash folder (if your desktop environment uses the
FreeDesktop.org Trash specification). One of the unique features of rmw
is the ability to purge items from your waste (or trash) directories
after x number of days.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Ddocdir=%{_docdir}/%{name} \
	--buildtype=release \
	-Dstrip=true \
    -Db_sanitize=none
%meson_build

%install
%meson_install

rm %{buildroot}%{_docdir}/%{name}/COPYING
%find_lang %{name}

%check
%meson_test

%files
%license COPYING
%{_bindir}/*
%{_docdir}/%{name}
%{_mandir}/man?/*1%{?ext_man}

%files lang -f %{name}.lang
%license COPYING

%changelog
* Thu Nov  7 2024 Andy Alt <arch_stanton5995@proton.me>
- rmw 0.9.3:
  + Add support for cloning(moving) files across btrfs root and subvolumes;
    thanks to @luigir-it for suggesting this feature and testing
  * Ensure directories respect umask settings upon creation
  * bugfix: In some cases, 'rmw -s' crashed with message "*** buffer overflow
    detected ***: terminated". This could happen if compiled with
    '-D_FORTIFY_SOURCE=3' and set up with 'b_sanitize=none', and depending on
    the filenames in the waste directories
  * Add completion for fishshell; thanks to @ccoVeille
  * Fix for tests failing after the Epochalypse (#439); thanks to @bmwiedemann
    (boo#1102840)
  + Add French translation (partial)
- drop patches included upstream:
  * test-restore-fix-use-Xvfb.patch
  * tests-fail-after-epochalypse.patch
* Mon Oct 21 2024 Andy Alt <arch_stanton5995@proton.me>
- Replace tests-fail-after-epochalypse.patch (code introduced in original patch
  not fully tested)
* Tue Mar 26 2024 Andy Alt <arch_stanton5995@proton.me>
- fix for tests failing after Epochalypse - add tests-fail-after-epochalypse.patch
  Reported by bmwiedemann while working on reproducible builds for OpenSuse
  (https://github.com/theimpossibleastronaut/rmw/issues/439)
* Wed Mar 20 2024 Andy Alt <arch_stanton5995@proton.me>
- fix and enable all tests - add test-restore-fix-use-Xvfb.patch
* Mon Mar 18 2024 Andreas Stieger <andreas.stieger@gmx.de>
- rmw 0.9.2:
  * Show counter in real-time as items are getting purged
* Wed May 17 2023 Andy Alt <arch_stanton5995@proton.me>
- rmw 0.9.1:
  * bugfix: In some cases, trashinfo file doesn't get removed
* Wed Feb 15 2023 Andy Alt <arch_stanton5995@proton.me>
- rmw 0.9.0:
  - When purging, '-ff' is no longer needed to confirm removal of
    non-writable expired directories and files
  * replace function used to remove directories with rm from FreeBSD;
    Thanks to @DiegoMagdaleno and @dcantrell
  * change message displayed to user when a file being rmw'ed is on a
    filesystem that doesn't haven't a WASTE folder defined
  + Ignore requests to ReMove top-level files, add --top-level-bypass option
    to bypass the protection
  + Ignore requests to ReMove user's home directory
  * bugfix: buffer underflow when calling trim_char() with empty
    string (Thanks to Christopher Wellons)
  * replace valgrind test setup with asan (-fsanitize)
  * the 'ESC' key can now be used to quit the restore file selection menu
* Tue Oct 25 2022 Andreas Stieger <andreas.stieger@gmx.de>
- disable tests
* Sat Feb  5 2022 Andreas Stieger <andreas.stieger@gmx.de>
- disable tests on 32 bit
* Wed Jan 26 2022 Andy Alt <andy400-dev@yahoo.com>
- rmw 0.8.1:
  * the curses menu library is now much more likely to be found on *BSD
  systems
  * bugfix: when attempting to restore a file from a waste folder
  listed in the config file that has a trailing slash, rmw will no
  longer report that the file is not in a waste folder.
  - curses is no longer a requirement (configure -Dwithout-curses=true)
  - removed '-e' command line option ('--empty' option not affected)
* Mon Jun 28 2021 Andy Alt <andy400-dev@yahoo.com>
- rmw 0.8.0:
  * The config option 'purge_after' has been deprecated and replaced
  with 'expire_age' ('purge_after' will still be accepted, but the user
  will be given a deprecation warning).
  * When '-u' is used, the mrl file will no longer be removed, but
  emptied instead. If a user gives the '-u' option when the mrl file is
  empty, they will get a friendlier message stating that there are no
  items in the list (instead of an error message about the file not
  being found).
  * fixed handling of dot dirs ('.' and '..'). Instead of giving an
  error message and quitting, rmw will print a message stating that
  they'll be skipped.
  * The environmental variable RMWTEST_HOME has been replaced with
  RMW_FAKE_HOME (Trying to use RMWTEST_HOME will give a deprecation
  warning and still work).
  * Expanded the man page and updated the README (improved documentation)
  * Replaced autotools build system with meson
  * rmw now uses the canfigger library for parsing the configuration file.
- disabled a restore test that failed when 'make check' is run with
  superuser privileges
* Sun May  9 2021 Andy Alt <andy400-dev@yahoo.com>
- rmw 0.7.09:
  * bugfix: filenames now display correctly when using '-vvg'
* Tue May  4 2021 Andreas Stieger <andreas.stieger@gmx.de>
- rmw 0.7.08, initial package
